<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 5/29/2012	ELL
// 
// 
// 
	
	include ("check_session.php");
	
	$class = $_POST['class'];
	$style_sheet = $_POST['style_sheet'];
	$class_table = $style_sheet . "_classes";
	
	$replace = array(".", "#", " ", ",");
	$search = array("PERIOD", "POUND", "SPACE", "COMMA");
	$class = str_replace($search, $replace, $class);
	
	$query = "SELECT `description` FROM `" . BWB_TABLE_PREFIX . $class_table . "` WHERE `class`='" . $class . "'";
	$result = $bwb_dbh->query($query);
	
	if ($result->rowCount() < 1)
	{
		echo "-no data-";
		exit;
	}

	$row = $result->fetch(PDO::FETCH_ASSOC);
	echo $row['description'];

?>